// Fetch the CSV data from the provided URL
const csvUrl =
  'https://gist.githubusercontent.com/Rekha-Telkapally/5fd9c2248db0d83914450969765eb54e/raw/add163ad80b6b4495f7713a1fc717d57f291c110/MobilePhones.csv';

// Use d3.csv() to fetch the data
d3.csv(csvUrl).then(function (data) {
  // Aggregate data by brand and calculate total sales for each brand
  const salesByBrand = d3.rollup(
    data,
    (v) => d3.sum(v, (d) => +d.Sales),
    (d) => d.Brand,
  );

  // Convert aggregated data to array of objects
  const salesData = Array.from(
    salesByBrand,
    ([brand, sales]) => ({ brand, sales }),
  );

  // Set up pie chart dimensions
  const width = 500;
  const height = 500;
  const radius = Math.min(width, height) / 2;

  // Set up color scale
  const color = d3.scaleOrdinal(d3.schemeCategory10);

  // Create SVG element
  const svg = d3
    .select('.pie-chart')
    .append('svg')
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .attr(
      'transform',
      `translate(${width / 2}, ${height / 2})`,
    );

  // Generate pie chart layout
  const pie = d3.pie().value((d) => d.sales);

  // Generate arcs for each pie slice
  const arc = d3.arc().innerRadius(0).outerRadius(radius);

  // Draw pie slices
  const arcs = svg
    .selectAll('arc')
    .data(pie(salesData))
    .enter()
    .append('g')
    .attr('class', 'arc');

  // Append path for each arc
  arcs
    .append('path')
    .attr('d', arc)
    .attr('fill', (d, i) => color(i));

  // Add labels
  arcs
    .append('text')
    .attr(
      'transform',
      (d) => `translate(${arc.centroid(d)})`,
    )
    .attr('text-anchor', 'middle')
    .text((d) => `${d.data.brand} - ${d.data.sales}`);

  // Create legend
  const legend = d3
    .select('.pie-chart')
    .append('div')
    .attr('class', 'legend')
    .style('position', 'absolute')
    .style('left', `${width}px`)
    .style('top', '50%')
    .style('transform', 'translateY(-50%)');

  // Add legend items
  const legendItems = legend
    .selectAll('.legend-item')
    .data(salesData)
    .enter()
    .append('div')
    .attr('class', 'legend-item');

  // Add colored rectangles to legend
  legendItems
    .append('div')
    .attr('class', 'legend-icon')
    .style('background-color', (d, i) => color(i))
    .style('width', '20px') // Set width of the colored rectangle
    .style('height', '10px') // Set height of the colored rectangle
    .style('margin-right', '5px'); // Add margin between icon and text

  // Add text to legend
  legendItems
    .append('div')
    .attr('class', 'legend-text')
    .text((d) => d.brand);
});
